# hypothetical - Hypothesis and Statistical Testing in Python

[![Build Status](https://travis-ci.org/aschleg/hypy.svg?branch=master)](https://travis-ci.org/aschleg/hypy)
[![Build status](https://ci.appveyor.com/api/projects/status/i1i1blt9ny3tyi6a?svg=true)](https://ci.appveyor.com/project/aschleg/hypy)
[![Coverage Status](https://coveralls.io/repos/github/aschleg/hypy/badge.svg)](https://coveralls.io/github/aschleg/hypy)

Python library for conducting hypothesis and other group comparison tests.

## Available Methods

### Hypothesis Testing

* t-test (one and two-sample)
* Mann-Whitney (two sample nonparametric variant of t-test)
* Wilcoxon Rank Sum Test (one sample nonparametric test)

### Analysis of Variance

* Analysis of Variance

## Features

### Critical Value Tables

* Wilcoxon Rank Sum W Statistic

## Goal

## Motivation

## Requirements

* Python 3.4+
* pandas >= 0.22.0
* numpy >= 1.13.0
* numpy_indexed >= 0.3.5

## Installation